==> dycdtools_0.1.0.tar.gz: dycdtools/R/Fun_Scatter-plot.R <==
#' Scatter plot of sim and obs var values
#'
#' @param sim interpolated values of variable.
#' @param obs observed values of variable. This data need to have fixed types of colnames and orders.
#' @param sim.start,sim.end the beginning and ending simulation dates for the intended DYRESM-CAEDYM model run. The date format must be "\%Y-\%m-\%d".
#' @param plot.start,plot.end the beginning and ending dates for the plotting purpose. The date format must be "\%Y-\%m-\%d".
#' @param min.depth,max.depth,by.value minimum and maximum depth for the profile plot at the depth increment of by.value.
#' @param plot.save if TRUE, the plot is saved with the "height","width", and "ppi" parameters.
#' @param file_name the file path to save the generated scatter plot.
#' @param height,width the height and width of the scatter figure.
#'
#' @import hydroGOF
#' @import ggplot2
#' @importFrom RColorBrewer brewer.pal
#' @importFrom graphics plot
#' @return a scatter plot of sim vs. obs
#'
#' @examples
#'  var.values<-ext.output(dycd.output=system.file("extdata", "dysim.nc", package = "dycdtools"),
#'                        var.extract=c("TEMP"))
#'
#'  for(i in 1:length(var.values)){
#'    expres<-paste0(names(var.values)[i],"<-data.frame(var.values[[",i,"]])")
#'    eval(parse(text=expres))
#'   }
#'
#' # interpolate temperature for depths from 0 to 13 m at increment of 0.5 m
#'   temp.interpolated<-interpol(layerHeights = dyresmLAYER_HTS_Var,
#'                              var = dyresmTEMPTURE_Var,
#'                              min.dept = 0,max.dept = 13,by.value = 0.5)
#'
#'  data(obs_temp)
#'
#' # scatter plot of sim and obs temperature
#'  scatter.plot(sim=temp.interpolated,
#'               obs=obs_temp,
#'               sim.start="2017-06-06",
#'               sim.end="2017-06-15",
#'               plot.start="2017-06-06",
#'               plot.end="2017-06-15",
#'               plot.save=FALSE,
#'               min.depth = 0,max.depth = 13,by.value = 0.5)
#'
#'
#' @export

scatter.plot<-function(sim=temp.interpolated,
                       obs=obs.temp,
                       sim.start="2017-06-06",
                       sim.end="2020-02-29",
                       plot.start="2017-06-06",
                       plot.end="2020-02-29",
                       min.depth=0,max.depth,by.value,
                       plot.save=TRUE,
                       file_name,
                       height=4,
                       width=7){

  #---
  # 1. simulation period
  #---
  sim.date<-seq.Date(from = as.Date(sim.start,format="%Y-%m-%d"),
                     to = as.Date(sim.end,format="%Y-%m-%d"),
                     by="day")

  #---
  # 2. combine sim with obs by Date and Depth
  #---
  sim.temp<-as.data.frame(sim)
  colnames(sim.temp)<-sim.date
  sim.temp$Depth<-seq(min.depth,max.depth,by=by.value)

  colnames(obs)<-c("Date","Depth","Value")
  obs<-obs%>%
    mutate(Date=as.Date(Date,format="%Y-%m-%d"))

  temp.both<-sim.temp%>%
    pivot_longer(-Depth,names_to = "Date",values_to = "sim")%>%
    mutate(Date=as.Date(Date,format="%Y-%m-%d"))%>%
    right_join(.,obs,by=c("Date","Depth"))%>%
    filter(Date>=plot.start&Date<=plot.end)

  colnames(temp.both)[4]<-"obs"

  #---
  # 3.report two objective functions' value and scatter plot sim vs. obs
  #---
  #message(NSE(temp.both$sim,obs=temp.both$obs))   #NSE
  #message(sqrt(mean((temp.both$sim-temp.both$obs)^2,na.rm = TRUE)))  # RMSE

  p<-temp.both%>%
    ggplot(aes(x=obs,y=sim,colour=Depth))+
    geom_point()+
    geom_abline(color="red")+
    scale_color_gradientn(colors = brewer.pal(11, "Spectral"), name = "Depth (m)")+
    xlab("Observed")+
    ylab("Simulated")+
    theme_classic()

  plot(p)

  if(plot.save){
    p+ggsave(filename = file_name,height = height,width = width)
  }
}

==> dycdtools_0.2.0.tar.gz: dycdtools/R/Fun_Scatter-plot.R <==
#' Scatter plot of sim and obs var values
#'
#' @param sim interpolated values of variable.
#' @param obs observed values of variable. This data need to have fixed types of colnames and orders.
#' @param sim.start,sim.end the beginning and ending simulation dates for the intended DYRESM-CAEDYM model run. The date format must be "\%Y-\%m-\%d".
#' @param plot.start,plot.end the beginning and ending dates for the plotting purpose. The date format must be "\%Y-\%m-\%d".
#' @param min.depth,max.depth,by.value minimum and maximum depth for the profile plot at the depth increment of by.value.
#' @param plot.save if TRUE, the plot is saved with the "height","width", and "ppi" parameters.
#' @param file_name the file path to save the generated scatter plot.
#' @param height,width the height and width of the scatter figure.
#'
#' @import hydroGOF
#' @import ggplot2
#' @importFrom RColorBrewer brewer.pal
#' @importFrom graphics plot
#' @return a scatter plot of sim vs. obs
#'
#' @examples
#'  var.values<-ext.output(dycd.output=system.file("extdata", "dysim.nc", package = "dycdtools"),
#'                        var.extract=c("TEMP"))
#'
#'  for(i in 1:length(var.values)){
#'    expres<-paste0(names(var.values)[i],"<-data.frame(var.values[[",i,"]])")
#'    eval(parse(text=expres))
#'   }
#'
#' # interpolate temperature for depths from 0 to 13 m at increment of 0.5 m
#'   temp.interpolated<-interpol(layerHeights = dyresmLAYER_HTS_Var,
#'                              var = dyresmTEMPTURE_Var,
#'                              min.dept = 0,max.dept = 13,by.value = 0.5)
#'
#'  data(obs_temp)
#'
#' # scatter plot of sim and obs temperature
#'  plot_scatter(sim=temp.interpolated,
#'               obs=obs_temp,
#'               sim.start="2017-06-06",
#'               sim.end="2017-06-15",
#'               plot.start="2017-06-06",
#'               plot.end="2017-06-15",
#'               plot.save=FALSE,
#'               min.depth = 0,max.depth = 13,by.value = 0.5)
#'
#'
#' @export

plot_scatter<-function(sim=temp.interpolated,
                       obs=obs.temp,
                       sim.start="2017-06-06",
                       sim.end="2020-02-29",
                       plot.start="2017-06-06",
                       plot.end="2020-02-29",
                       min.depth=0,max.depth,by.value,
                       plot.save=TRUE,
                       file_name,
                       height=4,
                       width=7){

  #---
  # 1. simulation period
  #---
  sim.date<-seq.Date(from = as.Date(sim.start,format="%Y-%m-%d"),
                     to = as.Date(sim.end,format="%Y-%m-%d"),
                     by="day")

  #---
  # 2. combine sim with obs by Date and Depth
  #---
  sim.temp<-as.data.frame(sim)
  colnames(sim.temp)<-sim.date
  sim.temp$Depth<-seq(min.depth,max.depth,by=by.value)

  colnames(obs)<-c("Date","Depth","Value")
  obs<-obs%>%
    mutate(Date=as.Date(Date,format="%Y-%m-%d"))

  temp.both<-sim.temp%>%
    pivot_longer(-Depth,names_to = "Date",values_to = "sim")%>%
    mutate(Date=as.Date(Date,format="%Y-%m-%d"))%>%
    right_join(.,obs,by=c("Date","Depth"))%>%
    filter(Date>=plot.start&Date<=plot.end)

  colnames(temp.both)[4]<-"obs"

  #---
  # 3.report two objective functions' value and scatter plot sim vs. obs
  #---

  p<-temp.both%>%
    ggplot(aes(x=obs,y=sim,colour=Depth))+
    geom_point()+
    geom_abline(color="red")+
    scale_color_gradientn(colors = brewer.pal(11, "Spectral"), name = "Depth (m)")+
    xlab("Observed")+
    ylab("Simulated")+
    theme_classic()

  plot(p)

  if(plot.save){
    p+ggsave(filename = file_name,height = height,width = width)
  }
}
